package com.persagy.dmp.file.controller;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.dmp.common.utils.ResourceUtil;
import com.persagy.dmp.file.service.CompatibleOldFileService;
import lombok.RequiredArgsConstructor;
import org.springframework.core.io.Resource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/***
 * Description: 兼容旧的文件服务接口
 * @author : lijie
 * Update By lijie 2021/11/18 10:06
 */
@Controller
@RequiredArgsConstructor
public class CompatibleOldFileController {

    private static final String DOCUMENTATION= "doc/documentation.md";
    private static final String TEMPLATE= "doc/template.html";
    private static final String ERROR_HTML="<html><head>" +
            "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"/>" +
            "<title>image-service</title></head></html><body>{}</body>";
    private final CompatibleOldFileService compatibleOldFileService;

    /***
     * Description: 获取接口文档
     * @param response : 响应体
     * @author : lijie
     * Update By lijie 2021/11/19 9:57
     */
    @GetMapping(value = "/doc",produces = {"text/html;charset=UTF-8"})
    public void doc(HttpServletResponse response) throws IOException {
        Resource[] docResources = ResourceUtil.getResource(DOCUMENTATION, DOCUMENTATION);
        Resource[] templateResources = ResourceUtil.getResource(TEMPLATE, TEMPLATE);
        if (templateResources.length<=0
                || docResources.length<=0
                || !templateResources[0].exists()
                || !docResources[0].exists()){
            response.getWriter()
                    .write(StrUtil.format(ERROR_HTML,"暂无内容"));
            return;
        }
        Resource docResource = docResources[0];
        Resource templateResource = templateResources[0];
        String tempStr = FileUtil.readString(templateResource.getFile(), Charset.defaultCharset());
        String docContentStr = FileUtil.readString(docResource.getFile(), Charset.defaultCharset());
        response.getWriter()
                .write(StrUtil.replace(tempStr, "#replaceMePlease#", docContentStr));
    }
    /***
     * Description: 工单文件上传
     * @return : void
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @PostMapping(value = "/work_order/upload",consumes = {"image/jpg"})
    @ResponseBody
    public String workOrderFileUpload(HttpServletRequest request) throws IOException {
        return compatibleOldFileService.uploadWorkOrderFile(request.getInputStream());
    }
    /***
     * Description: 文件上传
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @GetMapping(value = "/work_order/get",produces = {"image/jpg"})
    public void workOrderFileGet(HttpServletResponse response) {
        compatibleOldFileService.getWorkOrderFile(response);
    }

    /***
     * Description: 文件上传
     * @return : void
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @PostMapping(value = "/common/file_upload")
    @ResponseBody
    public String fileUpload(HttpServletRequest request) throws IOException {
        return compatibleOldFileService.uploadFile(request.getInputStream());
    }
    /***
     * Description: 图片上传
     * @return : void
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @PostMapping(value = "/common/image_upload",consumes = {"image/jpg"})
    @ResponseBody
    public String imageUpload(HttpServletRequest request) throws IOException {
        return compatibleOldFileService.uploadFile(request.getInputStream());
    }
    /***
     * Description: 图片下载
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @GetMapping(value = "/common/image_get")
    public void imageGet(HttpServletResponse response) {
        compatibleOldFileService.getFile(response);
        response.setContentType("image/jpg");
    }
    /***
     * Description: 图片下载
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @GetMapping(value = "/common/svg_get")
    public void imageSvgGet(HttpServletResponse response) {
        compatibleOldFileService.getFile(response);
        response.setContentType("image/svg+xml");
    }
    /***
     * Description: 图片下载
     * @return : void
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @PostMapping(value = "/common/images_list")
    @ResponseBody
    public JSONObject imagesList(@RequestBody(required = false) JSONObject param) {
        List<String> fileIds = compatibleOldFileService.listFiles(param);
        JSONObject result = new JSONObject();
        result.put("result", "success");
        result.put("Count", (long)fileIds.size());
        result.put("Content", fileIds);
        result.put("ResultMsg", "");
        return result;
    }
    /***
     * Description: 图片删除
     * @return : void
     * @author : lijie
     * Update By lijie 2021/11/19 9:58
     */
    @PostMapping(value = "/common/images_delete")
    @ResponseBody
    public JSONObject imageDelete(@RequestBody(required = false) JSONObject param){
        JSONObject result = new JSONObject();
        result.put("result", "success");
        result.put("Count", 0L);
        result.put("Content", new ArrayList<>());
        result.put("ResultMsg", "");
        JSONArray keys = param.getJSONArray("keys");
        if (null==keys || keys.size()<=0){
            return result;
        }
        List<String> deleteKeys = JSONArray.parseArray(JSON.toJSONString(keys), String.class);
        Set<String> fileIds = compatibleOldFileService.deleteFileByIds(deleteKeys);
        result.put("Count",fileIds.size());
        result.put("Content",fileIds);
        return result;
    }



}
